@@ -1,15 +1,13 @@
 #
 
-
 """ Module main entry point
 """
 
+import sys
 
 from . import cli
 
-
 if __name__ == '__main__':
-    cli.main()
-
+    sys.exit(cli.main())
 
 # EOF
