@@ -1,17 +1,14 @@
 #
 
-
 """ Command line interface
 """
 
-
 import argparse
 
 from . import _i18n
 from . import _meta
 from . import _pkg_resources
 
-
 _ = _i18n._
 
 
@@ -20,12 +17,12 @@ def main():
     """
     args_parser = argparse.ArgumentParser(
         allow_abbrev=False,
-        description=_meta.SUMMARY,
+        description=_meta.get_summary(),
     )
     args_parser.add_argument(
         '--version',
         action='version',
-        version=_meta.VERSION,
+        version=_meta.get_version(),
     )
     args_parser.add_argument(
         '-r',
